![Logo](/docs/SVG/logo-transparent.svg)

<p align="center">
    <img alt="Framework Version" src="https://img.shields.io/badge/latest_version-0.1.0b1-A04">
    <img alt="Python Version" src="https://img.shields.io/badge/python-3.12-A04">
    <img alt="PyPi" src="https://img.shields.io/badge/pypi-not_yet-000">
    <img alt="Issues" src="https://img.shields.io/github/issues/darky-bot/TwilightVK">
</pg>

## TwilightVK

TwilightVK - это асинхронный фреймворк для удобного взаимодействия с VK API, вдохновленный другими похожими фреймворками.

## Руководство

Здесь вы можете ознакомиться с тем как использовать данный фреймворк
+ [Содержание](/docs/content.md)

## Почему TwilightVK?

TwilightVK является личным экспериментом и не обязывает вас сравнивать его с другими фреймворками. У него, как и у других, есть свои плюсы и минусы.
В TwilightVK есть поддержка API эндпоинтов, позволяющая удобно управлять одним или группой ботов через единый API фреймворка

Планируется также собственная админ-панель привязанная к этому API
> ##### ! Еще в разработке !

> ##### ! Для работы API необходимо использовать TwilightAPI !

## Установка

Установить фреймворк можно через команду `pip install`

    pip install twilight_vk